package com.application.GUI.Panes;

import com.application.DB.Constants;
import com.application.GUI.LineChartFunctionality;
import com.application.GUI.PopUpWindows.NotificationPopUp;
import com.application.Main;
import javafx.scene.control.CheckMenuItem;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuItem;

public class CreateMenuBar {
    private final Main main;

    public CreateMenuBar(Main main) {
        this.main = main;
    }

    /**
     * Creates the menubar with buttons.
     * Defines each action when button is clicked.
     *
     * @return MenuBar as a HBox
     */
    public javafx.scene.control.MenuBar createMenuBar() {

        // Creating a menubar
        javafx.scene.control.MenuBar menuBar = new javafx.scene.control.MenuBar();

        // Defining the individual menus
        Menu menuFile = new Menu("File");
        Menu menuView = new Menu("View");
        Menu menuHelp = new Menu("Help");

        MenuItem menuFileExit = new MenuItem("Exit");
        menuFileExit.setOnAction(event -> Main.exitApplication());

        Main.setMenuViewLiveData(new CheckMenuItem("Live Data"));
        main.setMenuViewRegression(new CheckMenuItem("Regression"));
        main.setMenuViewRegressionShadow(new CheckMenuItem("Regression Shadow"));
        main.setMenuViewPreviousData(new CheckMenuItem("Previous Data"));

        Main.getMenuViewLiveData().setSelected(Constants.DEFAULT_IS_SELECTED_LIVE_DATA);
        Main.getMenuViewRegression().setSelected(Constants.DEFAULT_IS_SELECTED_REGRESSION);
        Main.getMenuViewRegressionShadow().setSelected(Constants.DEFAULT_IS_SELECTED_REGRESSION_SHADOW);
        Main.getMenuViewPreviousData().setSelected(Constants.DEFAULT_IS_SELECTED_PREVIOUS_DATA);

        Main.getMenuViewLiveData().setOnAction(event -> {
            if (Main.getMenuViewLiveData().isSelected()) {
                LineChartFunctionality.setPrintLiveData(true);
                LineChartFunctionality.printGraphs();
            } else {
                LineChartFunctionality.setPrintLiveData(false);
                LineChartFunctionality.printGraphs();
            }
        });
        Main.getMenuViewRegression().setOnAction(event -> {
            if (Main.getMenuViewRegression().isSelected()) {
                LineChartFunctionality.setPrintRegression(true);
                LineChartFunctionality.printGraphs();
            } else {
                LineChartFunctionality.setPrintRegression(false);
                LineChartFunctionality.printGraphs();
            }
        });
        Main.getMenuViewRegressionShadow().setOnAction(event -> {
            if (Main.getMenuViewRegressionShadow().isSelected()) {
                LineChartFunctionality.setPrintRegressionConfidenceInterval(true);
                LineChartFunctionality.printGraphs();
            } else {
                LineChartFunctionality.setPrintRegressionConfidenceInterval(false);
                LineChartFunctionality.printGraphs();
            }
        });
        Main.getMenuViewPreviousData().setOnAction(event -> {
            if (Main.getMenuViewPreviousData().isSelected()) {
                LineChartFunctionality.setPrintPreviousData(true);
                LineChartFunctionality.printGraphs();
            } else {
                LineChartFunctionality.setPrintPreviousData(false);
                LineChartFunctionality.printGraphs();
            }
        });

        MenuItem aboutUs = new MenuItem("About Us");
        aboutUs.setOnAction(event -> getAboutUs());
        MenuItem help = new MenuItem("Help");
        help.setOnAction(event -> getHelp());


        menuFile.getItems().addAll(menuFileExit);
        menuView.getItems().addAll(Main.getMenuViewLiveData(), Main.getMenuViewRegression(), Main.getMenuViewRegressionShadow(), Main.getMenuViewPreviousData());
        menuHelp.getItems().addAll(aboutUs, help);

        // Adding the menus to the menubar
        menuBar.getMenus().addAll(menuFile, menuView, menuHelp);

        // Returns the menubar
        return menuBar;
    }

    private static void getAboutUs(){
        String message = "Hei! Dette er en veldig lang string som sikkert går utenfor window! Dette er About us section!";
        NotificationPopUp.displayNotificationWindow(message);
    }

    private static void getHelp(){
        String message = "Hei! Dette er en veldig lang string som sikkert går utenfor window! Dette er Help section!";
        NotificationPopUp.displayNotificationWindow(message);
    }

}